@@ -15,7 +15,7 @@ use File::Spec;
 use File::Temp;
 use List::Util qw(sum);
 
-our $VERSION = '0.06';
+our $VERSION = '0.07';
 
 =head1 NAME
 
@@ -603,7 +603,7 @@ or through the web interface at L<http://rt.cpan.org>.
 James E. Keenan (jkeenan at cpan dot org).  When sending correspondence, please
 include 'Devel::Git::MultiBisect' or 'Devel-Git-MultiBisect' in your subject line.
 
-Creation date:  November 12 2016. Last modification date:  November 12 2016.
+Creation date:  November 16 2016. Last modification date:  November 16 2016.
 
 Development repository: L<https://github.com/jkeenan/devel-git-multibisect>
 
@@ -619,7 +619,11 @@ For naming suggestion: L<http://www.nntp.perl.org/group/perl.module-authors/2016
 
 =item * Ricardo Signes
 
-For feedback during inital development.
+For feedback during initial development.
+
+=item * Eily and Monk::Thomas
+
+For diagnosis of regex problems in http://perlmonks.org/?node_id=1175983.
 
 =back
 
